@@ -35,6 +35,7 @@ def main():
     parser.add_argument('command', nargs='*', default='')
     parser.add_argument('--noexecute', action='store_true', help='Deprecated')
     parser.add_argument('--nocache', action='store_true')
+    parser.add_argument('--nocleanup', action='store_true', help='do not remove the docker container when stopped')
     parser.add_argument('--pull', action='store_true')
     parser.add_argument('-v', '--version', action='version',
         version='%(prog)s ' + get_rocker_version())
@@ -68,7 +69,7 @@ def main():
         print("Build failed exiting")
         return exit_code
     # Convert command into string
-    args.command = ' '.join(args.command)
+    args.command = ' '.join(args.command) ## TODO(tfoote) Unused??
     return dig.run(**args_dict)
 
 
